@@ -1,5 +1,8 @@
 from yowsup.layers import YowLayer, YowLayerEvent, YowProtocolLayer
 from .protocolentities import ImageDownloadableMediaMessageProtocolEntity
+from .protocolentities import LocationMediaMessageProtocolEntity
+
+from .protocolentities import VCardMediaMessageProtocolEntity
 class YowMediaProtocolLayer(YowProtocolLayer):
     def __init__(self):
         handleMap = {
@@ -20,4 +23,10 @@ class YowMediaProtocolLayer(YowProtocolLayer):
             mediaNode = node.getChild("media")
             if mediaNode.getAttributeValue("type") == "image":
                 entity = ImageDownloadableMediaMessageProtocolEntity.fromProtocolTreeNode(node)
+                self.toUpper(entity)    
+            elif mediaNode.getAttributeValue("type") == "location":
+                entity = LocationMediaMessageProtocolEntity.fromProtocolTreeNode(node)
+                self.toUpper(entity)
+            elif mediaNode.getAttributeValue("type") == "vcard":
+                entity = VCardMediaMessageProtocolEntity.fromProtocolTreeNode(node)
                 self.toUpper(entity)
