@@ -1,3 +1,5 @@
 from .message_media import MediaMessageProtocolEntity
 from .message_media_downloadable import DownloadableMediaMessageProtocolEntity
-from .message_media_downloadable_image import ImageDownloadableMediaMessageProtocolEntity
\ No newline at end of file
+from .message_media_downloadable_image import ImageDownloadableMediaMessageProtocolEntity
+from .message_media_location import LocationMediaMessageProtocolEntity
+from .message_media_vcard import VCardMediaMessageProtocolEntity
